
function [I,x,w]=integrazione_gauss_jacobi(N,alpha,beta,f)
% INPUT:
% N: NUMERO NODI.
% alpha,beta: w(x)=((1-x)^alpha)*((1+x)^beta)
% f: INTEGRANDA (RISPETTO w) in (-1,1).
% OUTPUT:
% I: APPROSSIMAZIONE DI \int_a^b f(x) w(x) dx
% x,w: NODI/PESI UTILIZZATI.
ab=r_jacobi(N,alpha,beta); %TERM.RICORSIVI
xw=gauss(N,ab); %NODI/PESI IN MATRICE .
x=xw(:,1);w=xw(:,2);%NODI/PESI GAUSS JAC.[-1,1].
fx=feval(f,x);%VALUTAZIONE FUNZIONE.
I=w'*fx;%VALORE INTEGRALE.
